@@ -46,10 +46,10 @@ G_BEGIN_DECLS
 #define AGS_AUTOMATION_MINIMUM_ACCELERATION_LENGTH (1.0 / 16.0 / 64.0)
 #define AGS_AUTOMATION_MAXIMUM_ACCELERATION_LENGTH (16.0)
 
-#define AGS_AUTOMATION_DEFAULT_LENGTH (64 * 16 * 16 * 1200 / AGS_AUTOMATION_TICS_PER_BEAT)
+#define AGS_AUTOMATION_DEFAULT_LENGTH (64.0 * 16.0 * 16.0 * 1200.0 / AGS_AUTOMATION_TICS_PER_BEAT)
 #define AGS_AUTOMATION_DEFAULT_JIFFIE (60.0 / AGS_AUTOMATION_DEFAULT_BPM / AGS_AUTOMATION_TICS_PER_BEAT)
 #define AGS_AUTOMATION_DEFAULT_DURATION (AGS_AUTOMATION_DEFAULT_LENGTH * AGS_AUTOMATION_DEFAULT_JIFFIE * AGS_USEC_PER_SEC)
-#define AGS_AUTOMATION_DEFAULT_OFFSET (64 * (1 / AGS_AUTOMATION_MINIMUM_ACCELERATION_LENGTH))
+#define AGS_AUTOMATION_DEFAULT_OFFSET (64.0 * (1.0 / AGS_AUTOMATION_MINIMUM_ACCELERATION_LENGTH))
 
 #define AGS_AUTOMATION_DEFAULT_PRECISION (8)
 #define AGS_AUTOMATION_MAXIMUM_STEPS (128)
