@@ -69,9 +69,9 @@ static gpointer ags_set_buffer_size_parent_class = NULL;
 GType
 ags_set_buffer_size_get_type()
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__static = 0;
 
-  if(g_once_init_enter (&g_define_type_id__volatile)){
+  if(g_once_init_enter(&g_define_type_id__static)){
     GType ags_type_set_buffer_size = 0;
 
     static const GTypeInfo ags_set_buffer_size_info = {
@@ -91,10 +91,10 @@ ags_set_buffer_size_get_type()
 						      &ags_set_buffer_size_info,
 						      0);
 
-    g_once_init_leave(&g_define_type_id__volatile, ags_type_set_buffer_size);
+    g_once_init_leave(&g_define_type_id__static, ags_type_set_buffer_size);
   }
 
-  return g_define_type_id__volatile;
+  return(g_define_type_id__static);
 }
 
 void
